==> webkitgtk_2.3.2.orig.tar.xz: webkitgtk-2.3.2/Source/WebKit2/UIProcess/WebTextChecker.h <==
/*
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebTextChecker_h
#define WebTextChecker_h

#include "APIObject.h"
#include "WKTextChecker.h"
#include "WebTextCheckerClient.h"
#include <wtf/Forward.h>

namespace WebKit {

class WebPageProxy;

class WebTextChecker : public API::TypedObject<API::Object::Type::TextChecker> {
public:
    static WebTextChecker* shared();

    void setClient(const WKTextCheckerClient*);
    WebTextCheckerClient& client() { return m_client; }

    void continuousSpellCheckingEnabledStateChanged(bool);
    void grammarCheckingEnabledStateChanged(bool);

    void checkSpelling(const WebPageProxy*, bool startBeforeSelection);
    void changeSpellingToWord(const WebPageProxy*, const String&);

private:
    WebTextChecker();

    WebTextCheckerClient m_client;
};

} // namespace WebKit

#endif // WebTextChecker_h

==> webkitgtk_2.3.5.orig.tar.xz: webkitgtk-2.3.5/Source/WebKit2/UIProcess/WebTextChecker.h <==
/*
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebTextChecker_h
#define WebTextChecker_h

#include "APIObject.h"
#include "WKTextChecker.h"
#include "WebTextCheckerClient.h"
#include <wtf/Forward.h>

namespace WebKit {

class WebPageProxy;

class WebTextChecker : public API::ObjectImpl<API::Object::Type::TextChecker> {
public:
    static WebTextChecker* shared();

    void setClient(const WKTextCheckerClientBase*);
    WebTextCheckerClient& client() { return m_client; }

    void continuousSpellCheckingEnabledStateChanged(bool);
    void grammarCheckingEnabledStateChanged(bool);

    void checkSpelling(WebPageProxy*, bool startBeforeSelection);
    void changeSpellingToWord(WebPageProxy*, const String&);

private:
    WebTextChecker();

    WebTextCheckerClient m_client;
};

} // namespace WebKit

#endif // WebTextChecker_h
